@@ -14,6 +14,8 @@
 import ast
 import difflib
 import importlib
+import os
+import subprocess
 import typing
 from typing import Any, ClassVar, Dict, List, Optional
 
@@ -73,9 +75,13 @@ class InternalPythonInterpreter(BaseInterpreter):
             module and its submodule or function name are separated by a period
             (:obj:`.`). (default: :obj:`None`)
         unsafe_mode (bool, optional): If `True`, the interpreter runs the code
-            by `eval()` without any security check. (default: :obj:`False`)
+            by `eval()` or `exec()` without any security check.
+            (default: :obj:`False`)
         raise_error (bool, optional): Raise error if the interpreter fails.
             (default: :obj:`False`)
+        allow_builtins (bool, optional): If `True`, safe built-in functions
+            like print, len, str, etc. are added to the action space.
+            (default: :obj:`True`)
     """
 
     _CODE_TYPES: ClassVar[List[str]] = ["python", "py", "python3", "python2"]
@@ -86,6 +92,7 @@ class InternalPythonInterpreter(BaseInterpreter):
         import_white_list: Optional[List[str]] = None,
         unsafe_mode: bool = False,
         raise_error: bool = False,
+        allow_builtins: bool = True,
     ) -> None:
         self.action_space = action_space or dict()
         self.state = self.action_space.copy()
@@ -94,7 +101,54 @@ class InternalPythonInterpreter(BaseInterpreter):
         self.raise_error = raise_error
         self.unsafe_mode = unsafe_mode
 
-    def run(self, code: str, code_type: str) -> str:
+        # Add safe built-in functions if allowed
+        if allow_builtins:
+            self._add_safe_builtins()
+
+    def _add_safe_builtins(self):
+        r"""Add safe built-in functions to the action space."""
+        safe_builtins = {
+            'print': print,
+            'len': len,
+            'str': str,
+            'int': int,
+            'float': float,
+            'bool': bool,
+            'list': list,
+            'dict': dict,
+            'tuple': tuple,
+            'set': set,
+            'abs': abs,
+            'min': min,
+            'max': max,
+            'sum': sum,
+            'sorted': sorted,
+            'reversed': reversed,
+            'enumerate': enumerate,
+            'zip': zip,
+            'range': range,
+            'round': round,
+            'type': type,
+            'isinstance': isinstance,
+            'hasattr': hasattr,
+            'getattr': getattr,
+            'setattr': setattr,
+            'dir': dir,
+            'help': help,
+            'map': map,
+            'filter': filter,
+            'any': any,
+            'all': all,
+            'ord': ord,
+            'chr': chr,
+            'bin': bin,
+            'oct': oct,
+            'hex': hex,
+        }
+        self.action_space.update(safe_builtins)
+        self.state.update(safe_builtins)
+
+    def run(self, code: str, code_type: str = "python") -> str:
         r"""Executes the given code with specified code type in the
         interpreter.
 
@@ -102,15 +156,15 @@ class InternalPythonInterpreter(BaseInterpreter):
         type is supported, and then executes the code. If `unsafe_mode` is
         set to `False`, the code is executed in a controlled environment using
         the `execute` method. If `unsafe_mode` is `True`, the code is executed
-        using `eval()` with the action space as the global context. An
-        `InterpreterError` is raised if the code type is unsupported or if any
-        runtime error occurs during execution.
+        using `eval()` or `exec()` with the action space as the global context.
+        An `InterpreterError` is raised if the code type is unsupported or if
+        any runtime error occurs during execution.
 
         Args:
             code (str): The python code to be executed.
             code_type (str): The type of the code, which should be one of the
             supported code types (`python`, `py`, `python3`, `python2`).
-
+                (default: obj:`python`)
 
         Returns:
             str: The string representation of the output of the executed code.
@@ -125,10 +179,26 @@ class InternalPythonInterpreter(BaseInterpreter):
                 f"`{self.__class__.__name__}` only supports "
                 f"{', '.join(self._CODE_TYPES)}."
             )
-        if not self.unsafe_mode:
-            return str(self.execute(code))
+        if self.unsafe_mode:
+            import contextlib
+            import io
+
+            # Try to execute first and capture stdout
+            output_buffer = io.StringIO()
+            with contextlib.redirect_stdout(output_buffer):
+                exec(code, self.action_space)
+            result = output_buffer.getvalue()
+
+            # If no output was captured, try to evaluate the code
+            if not result:
+                try:
+                    result = str(eval(code, self.action_space))
+                except (SyntaxError, NameError):
+                    result = ""  # If eval fails, return empty string
+
+            return result
         else:
-            return str(eval(code, self.action_space))
+            return str(self.execute(code))
 
     def update_action_space(self, action_space: Dict[str, Any]) -> None:
         r"""Updates action space for *python* interpreter."""
@@ -404,7 +474,7 @@ class InternalPythonInterpreter(BaseInterpreter):
         result = None
         if not isinstance(if_statement.test, ast.Compare):
             raise InterpreterError(
-                "Only Campare expr supported in if statement, get"
+                "Only Compare expr supported in if statement, get"
                 f" {if_statement.test.__class__.__name__}"
             )
         if self._execute_condition(if_statement.test):
@@ -514,3 +584,27 @@ class InternalPythonInterpreter(BaseInterpreter):
                 return self.fuzz_state[close_matches[0]]
             else:
                 raise InterpreterError(f"The variable `{key}` is not defined.")
+
+    def execute_command(self, command: str) -> tuple[str, str]:
+        r"""Execute a command in the internal python interpreter.
+
+        Args:
+            command (str): The command to execute.
+
+        Returns:
+            tuple: A tuple containing the stdout and stderr of the command.
+        """
+        try:
+            proc = subprocess.Popen(
+                command,
+                stdout=subprocess.PIPE,
+                stderr=subprocess.PIPE,
+                text=True,
+                env=os.environ,
+                shell=True,
+            )
+            stdout, stderr = proc.communicate()
+
+            return stdout, stderr
+        except Exception as e:
+            raise InterpreterError(f"Error executing command: {e}")
