@@ -16,10 +16,22 @@ from typing import List, Optional
 
 from camel.memories.base import MemoryBlock
 from camel.memories.records import ContextRecord, MemoryRecord
-from camel.storages import BaseKeyValueStorage, InMemoryKeyValueStorage
+from camel.storages.key_value_storages.base import BaseKeyValueStorage
+from camel.storages.key_value_storages.in_memory import InMemoryKeyValueStorage
 from camel.types import OpenAIBackendRole
 
 
+class EmptyMemoryWarning(UserWarning):
+    """Warning raised when attempting to access an empty memory.
+
+    This warning is raised when operations are performed on memory
+    that contains no records. It can be safely caught and suppressed
+    in contexts where empty memory is expected.
+    """
+
+    pass
+
+
 class ChatHistoryBlock(MemoryBlock):
     r"""An implementation of the :obj:`MemoryBlock` abstract base class for
     maintaining a record of chat histories.
@@ -37,8 +49,8 @@ class ChatHistoryBlock(MemoryBlock):
         keep_rate (float, optional): In historical messages, the score of the
             last message is 1.0, and with each step taken backward, the score
             of the message is multiplied by the `keep_rate`. Higher `keep_rate`
-            leads to high possiblity to keep history messages during context
-            creation.
+            leads to high possibility to keep history messages during context
+            creation. (default: :obj:`0.9`)
     """
 
     def __init__(
@@ -69,13 +81,62 @@ class ChatHistoryBlock(MemoryBlock):
         """
         record_dicts = self.storage.load()
         if len(record_dicts) == 0:
-            warnings.warn("The `ChatHistoryMemory` is empty.")
+            warnings.warn(
+                "The `ChatHistoryMemory` is empty.",
+                EmptyMemoryWarning,
+                stacklevel=1,
+            )
             return list()
 
-        chat_records: List[MemoryRecord] = []
-        truncate_idx = -window_size if window_size is not None else 0
-        for record_dict in record_dicts[truncate_idx:]:
-            chat_records.append(MemoryRecord.from_dict(record_dict))
+        if window_size is not None and window_size >= 0:
+            # Initial preserved index: Keep first message
+            # if it's SYSTEM/DEVELOPER (index 0)
+            start_index = (
+                1
+                if (
+                    record_dicts
+                    and record_dicts[0]['role_at_backend']
+                    in {
+                        OpenAIBackendRole.SYSTEM.value,
+                        OpenAIBackendRole.DEVELOPER.value,
+                    }
+                )
+                else 0
+            )
+
+            """
+            Message Processing Logic:
+            1. Preserve first system/developer message (if needed)
+            2. Keep latest window_size messages from the rest
+            
+            Examples:
+            - Case 1: First message is SYSTEM, total 5 messages, window_size=2
+            Input: [system_msg, user_msg1, user_msg2, user_msg3, user_msg4]
+            Result: [system_msg] + [user_msg3, user_msg4]
+
+            - Case 2: First message is USER, total 5 messages, window_size=3
+            Input: [user_msg1, user_msg2, user_msg3, user_msg4, , user_msg5]
+            Result: [user_msg3, user_msg4, , user_msg5]
+            """
+            preserved_messages = record_dicts[
+                :start_index
+            ]  # Preserve system message (if exists)
+            sliding_messages = record_dicts[
+                start_index:
+            ]  # Messages to be truncated
+
+            # Take last window_size messages (if exceeds limit)
+            truncated_messages = sliding_messages[-window_size:]
+
+            # Combine preserved messages with truncated window messages
+            final_records = preserved_messages + truncated_messages
+        else:
+            # Return full records when no window restriction
+            final_records = record_dicts
+
+        chat_records: List[MemoryRecord] = [
+            MemoryRecord.from_dict(record) for record in final_records
+        ]
 
         # We assume that, in the chat history memory, the closer the record is
         # to the current message, the more score it will be.
@@ -85,13 +146,21 @@ class ChatHistoryBlock(MemoryBlock):
             if record.role_at_backend == OpenAIBackendRole.SYSTEM:
                 # System messages are always kept.
                 output_records.append(
-                    ContextRecord(memory_record=record, score=1.0)
+                    ContextRecord(
+                        memory_record=record,
+                        score=1.0,
+                        timestamp=record.timestamp,
+                    )
                 )
             else:
                 # Other messages' score drops down gradually
                 score *= self.keep_rate
                 output_records.append(
-                    ContextRecord(memory_record=record, score=score)
+                    ContextRecord(
+                        memory_record=record,
+                        score=score,
+                        timestamp=record.timestamp,
+                    )
                 )
 
         output_records.reverse()
