@@ -12,7 +12,9 @@
 # limitations under the License.
 # ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
 import os
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Union
+from typing import TYPE_CHECKING, Any, Dict, List, Optional, Type, Union
+
+from pydantic import BaseModel
 
 if TYPE_CHECKING:
     from mistralai.models import (
@@ -20,17 +22,26 @@ if TYPE_CHECKING:
         Messages,
     )
 
-from camel.configs import MISTRAL_API_PARAMS, MistralConfig
+from openai import AsyncStream
+
+from camel.configs import MistralConfig
+from camel.logger import get_logger
 from camel.messages import OpenAIMessage
 from camel.models import BaseModelBackend
-from camel.types import ChatCompletion, ModelType
+from camel.models._utils import try_modify_message_with_format
+from camel.types import ChatCompletion, ChatCompletionChunk, ModelType
 from camel.utils import (
     BaseTokenCounter,
     OpenAITokenCounter,
     api_keys_required,
     dependencies_required,
+    get_current_agent_session_id,
+    update_current_observation,
+    update_langfuse_trace,
 )
 
+logger = get_logger(__name__)
+
 try:
     if os.getenv("AGENTOPS_API_KEY") is not None:
         from agentops import LLMEvent, record
@@ -39,6 +50,14 @@ try:
 except (ImportError, AttributeError):
     LLMEvent = None
 
+if os.environ.get("LANGFUSE_ENABLED", "False").lower() == "true":
+    try:
+        from langfuse.decorators import observe
+    except ImportError:
+        from camel.utils import observe
+else:
+    from camel.utils import observe
+
 
 class MistralModel(BaseModelBackend):
     r"""Mistral API in a unified BaseModelBackend interface.
@@ -57,6 +76,14 @@ class MistralModel(BaseModelBackend):
         token_counter (Optional[BaseTokenCounter], optional): Token counter to
             use for the model. If not provided, :obj:`OpenAITokenCounter` will
             be used. (default: :obj:`None`)
+        timeout (Optional[float], optional): The timeout value in seconds for
+            API calls. If not provided, will fall back to the MODEL_TIMEOUT
+            environment variable or default to 180 seconds.
+            (default: :obj:`None`)
+        max_retries (int, optional): Maximum number of retries
+            for API calls. (default: :obj:`3`)
+        **kwargs (Any): Additional arguments to pass to the client
+            initialization.
     """
 
     @api_keys_required(
@@ -72,6 +99,9 @@ class MistralModel(BaseModelBackend):
         api_key: Optional[str] = None,
         url: Optional[str] = None,
         token_counter: Optional[BaseTokenCounter] = None,
+        timeout: Optional[float] = None,
+        max_retries: int = 3,
+        **kwargs: Any,
     ) -> None:
         from mistralai import Mistral
 
@@ -80,10 +110,25 @@ class MistralModel(BaseModelBackend):
 
         api_key = api_key or os.environ.get("MISTRAL_API_KEY")
         url = url or os.environ.get("MISTRAL_API_BASE_URL")
+        timeout = timeout or float(os.environ.get("MODEL_TIMEOUT", 180))
         super().__init__(
-            model_type, model_config_dict, api_key, url, token_counter
+            model_type,
+            model_config_dict,
+            api_key,
+            url,
+            token_counter,
+            timeout,
+            max_retries,
+            **kwargs,
+        )
+        self._client = Mistral(
+            timeout_ms=int(self._timeout * 1000)
+            if self._timeout is not None
+            else None,
+            api_key=self._api_key,
+            server_url=self._url,
+            **kwargs,
         )
-        self._client = Mistral(api_key=self._api_key, server_url=self._url)
 
     def _to_openai_response(
         self, response: 'ChatCompletionResponse'
@@ -212,29 +257,57 @@ class MistralModel(BaseModelBackend):
             )
         return self._token_counter
 
-    def run(
+    @observe(as_type="generation")
+    async def _arun(
         self,
         messages: List[OpenAIMessage],
-    ) -> ChatCompletion:
-        r"""Runs inference of Mistral chat completion.
+        response_format: Optional[Type[BaseModel]] = None,
+        tools: Optional[List[Dict[str, Any]]] = None,
+    ) -> Union[ChatCompletion, AsyncStream[ChatCompletionChunk]]:
+        logger.warning(
+            "Mistral does not support async inference, using sync "
+            "inference instead."
+        )
+        update_current_observation(
+            input={
+                "messages": messages,
+                "response_format": response_format,
+                "tools": tools,
+            },
+            model=str(self.model_type),
+            model_parameters=self.model_config_dict,
+        )
+        # Update Langfuse trace with current agent session and metadata
+        agent_session_id = get_current_agent_session_id()
+        if agent_session_id:
+            update_langfuse_trace(
+                session_id=agent_session_id,
+                metadata={
+                    "source": "camel",
+                    "agent_id": agent_session_id,
+                    "agent_type": "camel_chat_agent",
+                    "model_type": str(self.model_type),
+                },
+                tags=["CAMEL-AI", str(self.model_type)],
+            )
 
-        Args:
-            messages (List[OpenAIMessage]): Message list with the chat history
-                in OpenAI API format.
-
-        Returns:
-            ChatCompletion.
-        """
+        request_config = self._prepare_request(
+            messages, response_format, tools
+        )
         mistral_messages = self._to_mistral_chatmessage(messages)
 
         response = self._client.chat.complete(
             messages=mistral_messages,
             model=self.model_type,
-            **self.model_config_dict,
+            **request_config,
         )
 
         openai_response = self._to_openai_response(response)  # type: ignore[arg-type]
 
+        update_current_observation(
+            usage=openai_response.usage,
+        )
+
         # Add AgentOps LLM Event tracking
         if LLMEvent:
             llm_event = LLMEvent(
@@ -251,20 +324,95 @@ class MistralModel(BaseModelBackend):
 
         return openai_response
 
-    def check_model_config(self):
-        r"""Check whether the model configuration contains any
-        unexpected arguments to Mistral API.
+    @observe(as_type="generation")
+    def _run(
+        self,
+        messages: List[OpenAIMessage],
+        response_format: Optional[Type[BaseModel]] = None,
+        tools: Optional[List[Dict[str, Any]]] = None,
+    ) -> ChatCompletion:
+        r"""Runs inference of Mistral chat completion.
 
-        Raises:
-            ValueError: If the model configuration dictionary contains any
-                unexpected arguments to Mistral API.
+        Args:
+            messages (List[OpenAIMessage]): Message list with the chat history
+                in OpenAI API format.
+            response_format (Optional[Type[BaseModel]]): The format of the
+                response for this query.
+            tools (Optional[List[Dict[str, Any]]]): The tools to use for this
+                query.
+
+        Returns:
+            ChatCompletion: The response from the model.
         """
-        for param in self.model_config_dict:
-            if param not in MISTRAL_API_PARAMS:
-                raise ValueError(
-                    f"Unexpected argument `{param}` is "
-                    "input into Mistral model backend."
-                )
+        update_current_observation(
+            input={
+                "messages": messages,
+                "tools": tools,
+            },
+            model=str(self.model_type),
+            model_parameters=self.model_config_dict,
+        )
+        # Update Langfuse trace with current agent session and metadata
+        agent_session_id = get_current_agent_session_id()
+        if agent_session_id:
+            update_langfuse_trace(
+                session_id=agent_session_id,
+                metadata={
+                    "source": "camel",
+                    "agent_id": agent_session_id,
+                    "agent_type": "camel_chat_agent",
+                    "model_type": str(self.model_type),
+                },
+                tags=["CAMEL-AI", str(self.model_type)],
+            )
+
+        request_config = self._prepare_request(
+            messages, response_format, tools
+        )
+        mistral_messages = self._to_mistral_chatmessage(messages)
+
+        response = self._client.chat.complete(
+            messages=mistral_messages,
+            model=self.model_type,
+            **request_config,
+        )
+
+        openai_response = self._to_openai_response(response)  # type: ignore[arg-type]
+
+        update_current_observation(
+            usage=openai_response.usage,
+        )
+
+        # Add AgentOps LLM Event tracking
+        if LLMEvent:
+            llm_event = LLMEvent(
+                thread_id=openai_response.id,
+                prompt=" ".join(
+                    [message.get("content") for message in messages]  # type: ignore[misc]
+                ),
+                prompt_tokens=openai_response.usage.prompt_tokens,  # type: ignore[union-attr]
+                completion=openai_response.choices[0].message.content,
+                completion_tokens=openai_response.usage.completion_tokens,  # type: ignore[union-attr]
+                model=self.model_type,
+            )
+            record(llm_event)
+
+        return openai_response
+
+    def _prepare_request(
+        self,
+        messages: List[OpenAIMessage],
+        response_format: Optional[Type[BaseModel]] = None,
+        tools: Optional[List[Dict[str, Any]]] = None,
+    ) -> Dict[str, Any]:
+        request_config = self.model_config_dict.copy()
+        if tools:
+            request_config["tools"] = tools
+        elif response_format:
+            try_modify_message_with_format(messages[-1], response_format)
+            request_config["response_format"] = {"type": "json_object"}
+
+        return request_config
 
     @property
     def stream(self) -> bool:
