@@ -83,10 +83,17 @@ class StubModel(BaseModelBackend):
         url: Optional[str] = None,
         token_counter: Optional[BaseTokenCounter] = None,
         timeout: Optional[float] = None,
+        max_retries: int = 3,
     ) -> None:
         r"""All arguments are unused for the dummy model."""
         super().__init__(
-            model_type, model_config_dict, api_key, url, token_counter, timeout
+            model_type,
+            model_config_dict,
+            api_key,
+            url,
+            token_counter,
+            timeout,
+            max_retries,
         )
 
     @property
@@ -175,7 +182,3 @@ class StubModel(BaseModelBackend):
             ),
         )
         return response
-
-    def check_model_config(self):
-        r"""Directly pass the check on arguments to STUB model."""
-        pass
