@@ -19,17 +19,29 @@ from .base import (
     VectorDBStatus,
     VectorRecord,
 )
+from .chroma import ChromaStorage
+from .faiss import FaissStorage
 from .milvus import MilvusStorage
+from .oceanbase import OceanBaseStorage
+from .pgvector import PgVectorStorage
 from .qdrant import QdrantStorage
+from .surreal import SurrealStorage
 from .tidb import TiDBStorage
+from .weaviate import WeaviateStorage
 
 __all__ = [
     'BaseVectorStorage',
     'VectorDBQuery',
     'VectorDBQueryResult',
+    'ChromaStorage',
     'QdrantStorage',
     'MilvusStorage',
     "TiDBStorage",
+    'FaissStorage',
+    'OceanBaseStorage',
+    'WeaviateStorage',
     'VectorRecord',
     'VectorDBStatus',
+    'PgVectorStorage',
+    'SurrealStorage',
 ]
