@@ -1,23 +1,23 @@
-# =========== Copyright 2023 @ CAMEL-AI.org. All Rights Reserved. ===========
-# Licensed under the Apache License, Version 2.0 (the “License”);
+# ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
+# Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
 # You may obtain a copy of the License at
 #
 #     http://www.apache.org/licenses/LICENSE-2.0
 #
 # Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an “AS IS” BASIS,
+# distributed under the License is distributed on an "AS IS" BASIS,
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-# =========== Copyright 2023 @ CAMEL-AI.org. All Rights Reserved. ===========
+# ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
 import json
 import os
 from typing import Any, Callable, Dict, List, Optional, Tuple
 
 import requests
 
-from camel.toolkits import OpenAIFunction, openapi_security_config
+from camel.toolkits import FunctionTool, openapi_security_config
 from camel.types import OpenAPIName
 
 
@@ -526,12 +526,12 @@ class OpenAPIToolkit:
             apinames_filepaths.append((api_name.value, file_path))
         return apinames_filepaths
 
-    def get_tools(self) -> List[OpenAIFunction]:
-        r"""Returns a list of OpenAIFunction objects representing the
+    def get_tools(self) -> List[FunctionTool]:
+        r"""Returns a list of FunctionTool objects representing the
         functions in the toolkit.
 
         Returns:
-            List[OpenAIFunction]: A list of OpenAIFunction objects
+            List[FunctionTool]: A list of FunctionTool objects
                 representing the functions in the toolkit.
         """
         apinames_filepaths = self.generate_apinames_filepaths()
@@ -539,9 +539,6 @@ class OpenAPIToolkit:
             self.apinames_filepaths_to_funs_schemas(apinames_filepaths)
         )
         return [
-            OpenAIFunction(a_func, a_schema)
+            FunctionTool(a_func, a_schema)
             for a_func, a_schema in zip(all_funcs_lst, all_schemas_lst)
         ]
-
-
-OPENAPI_FUNCS: List[OpenAIFunction] = OpenAPIToolkit().get_tools()
