@@ -33,19 +33,21 @@ from openai.types.chat.chat_completion_user_message_param import (
 from openai.types.completion_usage import CompletionUsage
 from openai.types.chat import ParsedChatCompletion
 from openai._types import NOT_GIVEN, NotGiven
-from openai.types.chat import ChatCompletionMessageToolCall
+from openai.types.chat import ChatCompletionMessageFunctionToolCall
 
-Choice = Choice
-ChatCompletion = ChatCompletion
-ChatCompletionChunk = ChatCompletionChunk
-ChatCompletionMessage = ChatCompletionMessage
-ChatCompletionMessageParam = ChatCompletionMessageParam
-ChatCompletionSystemMessageParam = ChatCompletionSystemMessageParam
-ChatCompletionUserMessageParam = ChatCompletionUserMessageParam
-ChatCompletionAssistantMessageParam = ChatCompletionAssistantMessageParam
-ChatCompletionToolMessageParam = ChatCompletionToolMessageParam
-ChatCompletionMessageToolCall = ChatCompletionMessageToolCall
-CompletionUsage = CompletionUsage
-NOT_GIVEN = NOT_GIVEN
-NotGiven = NotGiven
-ParsedChatCompletion = ParsedChatCompletion
+__all__ = [
+    "Choice",
+    "ChatCompletion",
+    "ChatCompletionChunk",
+    "ChatCompletionMessage",
+    "ChatCompletionMessageParam",
+    "ChatCompletionSystemMessageParam",
+    "ChatCompletionUserMessageParam",
+    "ChatCompletionAssistantMessageParam",
+    "ChatCompletionToolMessageParam",
+    "ChatCompletionMessageFunctionToolCall",
+    "CompletionUsage",
+    "ParsedChatCompletion",
+    "NOT_GIVEN",
+    "NotGiven",
+]
