@@ -12,6 +12,7 @@
 # limitations under the License.
 # ========= Copyright 2023-2024 @ CAMEL-AI.org. All Rights Reserved. =========
 import logging
+from enum import Enum
 from threading import Lock
 from typing import TYPE_CHECKING, ClassVar, Dict, Union, cast
 
@@ -32,17 +33,28 @@ class UnifiedModelType(str):
     _lock: ClassVar[Lock] = Lock()
 
     def __new__(cls, value: Union["ModelType", str]) -> "UnifiedModelType":
+        if isinstance(value, Enum):
+            str_value = value.value
+        else:
+            str_value = str(value)
+
         with cls._lock:
-            if value not in cls._cache:
-                instance = super().__new__(cls, value)
-                cls._cache[value] = cast(UnifiedModelType, instance)
+            if str_value not in cls._cache:
+                instance = super().__new__(cls, str_value)
+                cls._cache[str_value] = cast(UnifiedModelType, instance)
             else:
-                instance = cls._cache[value]
+                instance = cls._cache[str_value]
         return instance
 
     def __init__(self, value: Union["ModelType", str]) -> None:
         pass
 
+    def __repr__(self) -> str:
+        return super().__str__()
+
+    def __str__(self) -> str:
+        return super().__str__()
+
     @property
     def value_for_tiktoken(self) -> str:
         r"""Returns the model name for TikToken."""
@@ -63,6 +75,11 @@ class UnifiedModelType(str):
         r"""Returns whether the model is an OpenAI model."""
         return True
 
+    @property
+    def is_aws_bedrock(self) -> bool:
+        r"""Returns whether the model is an AWS Bedrock model."""
+        return True
+
     @property
     def is_anthropic(self) -> bool:
         r"""Returns whether the model is an Anthropic model."""
@@ -78,11 +95,21 @@ class UnifiedModelType(str):
         r"""Returns whether the model is a Groq served model."""
         return True
 
+    @property
+    def is_nebius(self) -> bool:
+        r"""Returns whether the model is a Nebius AI Studio served model."""
+        return True
+
     @property
     def is_openrouter(self) -> bool:
         r"""Returns whether the model is a OpenRouter served model."""
         return True
 
+    @property
+    def is_lmstudio(self) -> bool:
+        r"""Returns whether the model is a LMStudio served model."""
+        return True
+
     @property
     def is_ppio(self) -> bool:
         r"""Returns whether the model is a PPIO served model."""
@@ -103,6 +130,11 @@ class UnifiedModelType(str):
         r"""Returns whether the model is a Mistral model."""
         return True
 
+    @property
+    def is_netmind(self) -> bool:
+        r"""Returns whether the model is a Netmind model."""
+        return True
+
     @property
     def is_reka(self) -> bool:
         r"""Returns whether the model is a Reka model."""
@@ -113,6 +145,11 @@ class UnifiedModelType(str):
         r"""Returns whether the model is a Cohere model."""
         return True
 
+    @property
+    def is_cometapi(self) -> bool:
+        r"""Returns whether the model is a CometAPI served model."""
+        return True
+
     @property
     def is_yi(self) -> bool:
         r"""Returns whether the model is a Yi model."""
@@ -138,6 +175,26 @@ class UnifiedModelType(str):
         r"""Returns whether this platform is Moonshot model."""
         return True
 
+    @property
+    def is_novita(self) -> bool:
+        r"""Returns whether the model is a Novita served model."""
+        return True
+
+    @property
+    def is_watsonx(self) -> bool:
+        r"""Returns whether the model is a WatsonX served model."""
+        return True
+
+    @property
+    def is_qianfan(self) -> bool:
+        r"""Returns whether the model is a Qianfan served model."""
+        return True
+
+    @property
+    def is_crynux(self) -> bool:
+        r"""Returns whether the model is a Crynux served model."""
+        return True
+
     @property
     def support_native_structured_output(self) -> bool:
         r"""Returns whether the model supports native structured output."""
